@@ -11,8 +11,8 @@ class Fluent:
     def __init__(self, host=None, port=None):
         self.sender = FluentSender(
             'letov',
-            host=host or os.environ['FLUENT_HOST'],
-            port=port or int(os.environ['FLUENT_PORT']),
+            host=host or os.environ['FLUENTBIT_HOST'],
+            port=port or int(os.environ['FLUENTBIT_PORT']),
             buffer_overflow_handler=self.overflow_handler
         )
 
@@ -21,10 +21,13 @@ class Fluent:
         unpacker = msgpack.Unpacker(BytesIO(pending), raw=False)
         for tag, ts, record in unpacker:
             # last resort - try to send logs through docker engine (stdout)
-            print(record['message'])
+            print(record['log'])
 
     def send(self, message):
-        return self.sender.emit('applogs', {'message': message})
+        return self.sender.emit('applogs', {
+            'log': message,
+            'source': 'letov',
+        })
 
     def close(self):
         self.sender.close()
